import React, { useEffect, useState } from "react";
import { Card } from "./Card/Card";
import { useFetchFlights } from "../../hooks/useFetchFlights";
import { Flight } from "../../Types";
import { useNavigate } from "react-router";
import useAuth from "../../useAuth";

interface Props {
    flights?: Flight[];
}

export const Home: React.FC<Props> = (props) => {
    const urlParams = new URLSearchParams(window.location.search);
    const origin = urlParams.get('origin');
    const initialPage = parseInt(urlParams.get('page') || '1', 10);
    const { flights, count, error } = useFetchFlights(origin, initialPage);
    const navigate = useNavigate()

    const [currentPage, setCurrentPage] = useState(initialPage);
    const { loading, isAirline } = useAuth();

    useEffect(() => {
        const newParams = new URLSearchParams(window.location.search);
        newParams.set('page', currentPage.toString());
        navigate(`?${newParams.toString()}`);
    }, [currentPage, navigate]);

    const goToPrevPage = () => {
        if (currentPage > 1) {
            setCurrentPage(currentPage - 1);
        }
    };

    const goToNextPage = () => {
        setCurrentPage(currentPage + 1);
    };

    const checkMaxPage = () => {
        return currentPage * 8 >= count ? false : true
    }

    const checkMinPage = () => {
        return currentPage > 1 ? true : false
    }

    if (loading) {
        return <div>Loading...</div>;
    }

    return (
        <div className="Box">
            {isAirline ? <button onClick={() => { navigate("/create-flight") }}>Create flight</button> : <></>}
            <h2>Flights</h2>
            <div className="Items">
                {(props.flights ? props.flights : flights).map((u) => {
                    return <Card key={u.id} flight={u} />;
                })}
                {error ? <div className="Disconnected">{error}</div> : <></>}
            </div>
            <div>
                {checkMinPage() && <button onClick={goToPrevPage}>Prev</button>}
                <span> Page {currentPage} </span>
                {checkMaxPage() && <button onClick={goToNextPage}>Next</button>}
            </div>
        </div>
    );
};
